@@ -1,12 +1,7 @@
 ".onLoad" <- function(lib,pkg) {
-  cat("\n**WARNING**\n\n")
-  cat("This is currently 'quantmod' version 0.1-0")
-  cat("\nMany functions, features, and documentation are\n")
-  cat("incomplete. A new package will be available on CRAN\n")
-  cat("on or around useR2007 in Ames, IA, USA\n\n")
-#  require(methods,quietly=TRUE);
-#  require(zoo,quietly=TRUE);
-#  require(RMySQL,quietly=TRUE);
+  cat("quantmod: Quantitative Financial Modelling Framework\n\n")
+  cat("Version 0-2.1\n")
+  cat("http://www.quantmod.com\n\n")
 }
 setOldClass("zoo");
 setOldClass("Date");
@@ -21,7 +16,7 @@ setClass("quantmod",representation(
                     product="character",
                     price.levels="zoo",
                     training.data="Date",
-                    build.date="Date",
+                    build.date="character",
                     fitted.model="ANY",
                     model.data="zoo",
                     quantmod.version="numeric"
@@ -178,7 +173,7 @@ function(x,...)
 'formula.quantmod' <-
 function(x,...)
 {
-    x@model.spec
+    x@model.formula
 }
 
 'coef.quantmod' <-
